package com.bonus.zlpt.equip.mapper;

import com.bonus.zlpt.equip.api.domain.LeaseInfo;

import java.util.List;

/**
 * 租赁信息Mapper接口
 * 
 * @author xsheng
 * @date 2023-12-02
 */
public interface LeaseInfoMapper 
{
    /**
     * 查询租赁信息
     * 
     * @param id 租赁信息主键
     * @return 租赁信息
     */
    public LeaseInfo selectLeaseInfoById(Long id);

    /**
     * 查询租赁信息列表
     * 
     * @param leaseInfo 租赁信息
     * @return 租赁信息集合
     */
    public List<LeaseInfo> selectLeaseInfoList(LeaseInfo leaseInfo);

    /**
     * 新增租赁信息
     * 
     * @param leaseInfo 租赁信息
     * @return 结果
     */
    public int insertLeaseInfo(LeaseInfo leaseInfo);

    /**
     * 修改租赁信息
     * 
     * @param leaseInfo 租赁信息
     * @return 结果
     */
    public int updateLeaseInfo(LeaseInfo leaseInfo);

    /**
     * 删除租赁信息
     * 
     * @param id 租赁信息主键
     * @return 结果
     */
    public int deleteLeaseInfoById(Long id);

    /**
     * 批量删除租赁信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLeaseInfoByIds(Long[] ids);
}
